package org.apache.commons.lang3.function;

import java.lang.Throwable;
import java.util.Objects;

@FunctionalInterface
/* loaded from: org_apache_commons_lang3_function.jar:org/apache/commons/lang3/function/FailableBiPredicate.class */
public interface FailableBiPredicate<T, U, E extends Throwable> {
    public static final FailableBiPredicate FALSE = (t, u) -> {
        return false;
    };
    public static final FailableBiPredicate TRUE = (t, u) -> {
        return true;
    };

    boolean test(T t, U u) throws Throwable;

    static <T, U, E extends Throwable> FailableBiPredicate<T, U, E> falsePredicate() {
        return FALSE;
    }

    static <T, U, E extends Throwable> FailableBiPredicate<T, U, E> truePredicate() {
        return TRUE;
    }

    default FailableBiPredicate<T, U, E> and(FailableBiPredicate<? super T, ? super U, E> other) {
        Objects.requireNonNull(other);
        return (obj, obj2) -> {
            return test(obj, obj2) && other.test(obj, obj2);
        };
    }

    default FailableBiPredicate<T, U, E> negate() {
        return (obj, obj2) -> {
            return !test(obj, obj2);
        };
    }

    default FailableBiPredicate<T, U, E> or(FailableBiPredicate<? super T, ? super U, E> other) {
        Objects.requireNonNull(other);
        return (obj, obj2) -> {
            return test(obj, obj2) || other.test(obj, obj2);
        };
    }
}
